rai\_toolbox.mushin.RobustnessCurve
===================================

.. currentmodule:: rai_toolbox.mushin

.. autoclass:: RobustnessCurve

   
   .. automethod:: __init__
   .. automethod:: run
   .. automethod:: plot
   .. automethod:: load_from_dir

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RobustnessCurve.__init__
      ~RobustnessCurve.task
      ~RobustnessCurve.jobs_post_process
      ~RobustnessCurve.load_from_dir
      ~RobustnessCurve.plot
      ~RobustnessCurve.run
      ~RobustnessCurve.to_xarray
      ~RobustnessCurve.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BaseWorkflow.cfgs
      ~BaseWorkflow.metrics
      ~BaseWorkflow.workflow_overrides
      ~BaseWorkflow.jobs
   